@@ -3,5 +3,5 @@
 """
 Пакет, содержащий набор вспомогательных функций, использующихся в различных классах PPL.
 """
-from .helper_funcs import TypeConverter, timing, raise_exception, log
+from .helper_funcs import TypeConverter, JSONDecoder, timing, raise_exception, log
 from .consts import *
