@@ -1,7 +1,7 @@
 #!/usr/bin/python3
 # -*- coding: utf-8 -*-
 """
-Описание типов и констант, использующихся в PPL.
+Описание типов данных и констант, использующихся в PPL.
 """
 
 from typing import NewType
@@ -32,6 +32,30 @@ CODE_NAME_MAP = {
     FORECAST_ID: 'Прогнозирование'
 }
 
+# соответствие числового и строкового типов, используемых Полиматикой
+POLYMATICA_INT_TYPES_MAP = {
+    0: 'uint8',
+    1: 'uint16',
+    2: 'uint32',
+    3: 'uint64',
+    4: 'double',
+    5: 'string',
+    6: 'date',
+    7: 'time',
+    8: 'datetime',
+    9: 'date_year',
+    10: 'date_quarter',
+    11: 'date_month',
+    12: 'date_day',
+    13: 'date_week',
+    14: 'date_wday',
+    15: 'time_hour',
+    16: 'time_minute',
+    17: 'time_second',
+    18: 'none',
+    19: 'unknown'
+}
+
 # соответствие типов, используемых Полиматикой, с типами данных Python Core
 TYPES_MAP = {
     'uint8': 'integer',
@@ -51,9 +75,39 @@ TYPES_MAP = {
     'date_wday': 'string',
     'time_hour': 'integer',
     'time_minute': 'integer',
-    'time_second': 'integer'
+    'time_second': 'integer',
+    'none': 'none',
+    'unknown': 'unknown'
 }
 
+# сопоставление положения размерности в мультисфере
+POSITION_MAP = {
+    0: 'out',
+    1: 'left',
+    2: 'up'
+}
+
+# описание типов фактов (строка - число)
+MEASURE_STR_INT_TYPES_MAP = {
+    "Значение": 0,
+    "Процент": 1,
+    "Ранг": 2,
+    "Количество уникальных": 3,
+    "Среднее": 4,
+    "Отклонение": 5,
+    "Минимум": 6,
+    "Максимум": 7,
+    "Изменение": 8,
+    "Изменение в %": 9,
+    "Нарастающее": 10,
+    "ABC": 11,
+    "Медиана": 12,
+    "Количество": 13
+}
+
+# описание типов фактов (число - строка)
+MEASURE_INT_STR_TYPES_MAP = {v:k for k, v in MEASURE_STR_INT_TYPES_MAP.items()}
+
 # месяцы
 MONTHS = ["Январь", "Февраль", "Март", "Апрель", "Май", "Июнь", "Июль", "Август", "Сентябрь", "Октябрь",
           "Ноябрь", "Декабрь"]
@@ -68,3 +122,5 @@ FUNCS = ["top", "total", "corr"]
 
 # прочие
 ISO_DATE_FORMAT = '%Y-%m-%d %H:%M:%S'
+ALL_PERMISSIONS = 31
+DEFAULT_POLYMATICA_VERSION = '5.6'
