@@ -6,7 +6,7 @@ import re
 import requests
 import datetime
 from typing import Dict, Union, Callable
-from .common import MONTHS, WEEK_DAYS, datetime_type
+from .common import MONTHS, WEEK_DAYS, datetime_type, FUNCS, LOGIC_FUNCS
 
 
 def request_asserts(response: Dict, r: requests.models.Response) -> bool:
@@ -47,13 +47,12 @@ def request_asserts(response: Dict, r: requests.models.Response) -> bool:
     return True
 
 
-def checks(self, func_name, *args):
+def checks(self, func_name: str, *args):
     """
     Реализация проверок различных функций.
     :param self: экземпляр класса BusinessLogic.
     :param func_name: название функции.
     :param args: прочие параметры, необходимые для проверки.
-    :return:
     """
     if func_name == "rename_group":
         group_uuid = args[0]
@@ -90,11 +89,15 @@ def checks(self, func_name, *args):
         if not isinstance(dim_name, str):
             raise ValueError('Dimension name "{}" is not valid. It should have "string" type'.format(dim_name))
         return True
-    elif func_name == "select_all_dims":
-        left_dims = args[0]
-        if not left_dims:
+    elif func_name == "select_unselect_impl":
+        left_dims, top_dims, position = args[0], args[1], args[2]
+        if position not in ["left", "top"]:
+            raise ValueError('Param "position" must be either "left" or "top"!')
+        if position == 'left' and not left_dims:
             raise ValueError("Left dimensions required!")
-        return True
+        if position == 'top' and not top_dims:
+            raise ValueError("Top dimensions required!")
+        return 1 if position == "left" else 2
     elif func_name == "set_measure_visibility":
         is_visible = args[0]
         if not isinstance(is_visible, bool):
@@ -106,19 +109,14 @@ def checks(self, func_name, *args):
             raise ValueError('Param "sort_type" can only equals "ascending" or "descending" or "off"!')
         return True
     elif func_name == "unfold_all_dims":
-        position = args[0]
-        level = args[1]
+        position, level = args[0], args[1]
         # проверка позиции
-        if position == "left":
-            int_position = 1
-        elif position == "up":
-            int_position = 2
-        else:
-            raise ValueError('Position "{}" does not exist! Position can only be "up" or "left"!'.format(position))
+        if position not in ["left", "up"]:
+            raise ValueError('Param "position" must be either "left" or "up"!')
         # проверка значения уровня
         if level < 0:
             raise ValueError('Param "level" can be only positive!')
-        return int_position
+        return 1 if position == "left" else 2
     elif func_name == "set_width_columns":
         measures, measures_list, left_dims, left_dims_data = args[0], args[1], args[2], args[3]
         error_msg = str()
@@ -131,6 +129,17 @@ def checks(self, func_name, *args):
         if error_msg:
             raise ValueError(error_msg)
         return True
+    elif func_name == "delete_dim_filter":
+        dim_name, filter_name, num_row = args[0], args[1], args[2]
+        if not isinstance(dim_name, str):
+            raise ValueError('Param "dim_name" must be "str" type!')
+        if not isinstance(num_row, int):
+            raise ValueError('Param "num_row" must be "int" type!')
+        if not isinstance(filter_name, (str, list, set, tuple)):
+            raise ValueError('Param "filter_name" must be one of following types: ["str", "list", "set", "tuple"]!')
+        if not filter_name:
+            raise ValueError('Param "filter_name" cannot be empty!')
+        return [filter_name] if isinstance(filter_name, str) else filter_name
     elif func_name == "put_dim_filter":
         filter_name, start_date, end_date, filter_field_format = args[0], args[1], args[2], args[3]
         if (filter_name is None) and (start_date is None and end_date is None):
@@ -396,5 +405,67 @@ def checks(self, func_name, *args):
             return dimensions
         else:
             raise ValueError('Param "dimensions" must be "str", "list" or "tuple" type!')
+    elif func_name == 'get_cube_info':
+        cube = args[0]
+        if not isinstance(cube, str):
+            raise ValueError('Param "cube" must be "str" type!')
+    elif func_name == 'clone_olap_module':
+        module, set_focus_on_copied_module, copied_module_name = args[0], args[1], args[2]
+        if not isinstance(module, str):
+            raise ValueError('Param "module" must be "str" type!')
+        if not isinstance(set_focus_on_copied_module, bool):
+            raise ValueError('Param "set_focus_on_copied_module" must be "bool" type!')
+        if not isinstance(copied_module_name, str):
+            raise ValueError('Param "copied_module_name" must be "str" type!')
+    elif func_name == 'create_calculated_measure':
+        measure_name, formula = args[0], args[1]
+        def check_type_and_value(param_value: str, param_name: str):
+            """
+            Проверка типа и значения заданного параметра.
+            Ничего не возвращает, но бросается ошибками.
+            """
+            if not isinstance(param_value, str):
+                raise ValueError('Param "{}" must be "str" type!'.format(param_name))
+            if not param_value:
+                raise ValueError('Param "{}" has empty value!'.format(param_name))
+        def check_new_name_param(measure_name: str):
+            """
+            Проверка имени создаваемого вычислимого факта на соответствие с названиями функций и логических операндов.
+            Ничего не возвращает, но бросается ошибками.
+            """
+            lower_measure_name = measure_name.lower()
+            if lower_measure_name in FUNCS or lower_measure_name in LOGIC_FUNCS or lower_measure_name == 'if':
+                raise ValueError('Value "{}" of "new_name" parameter is invalid!'.format(measure_name))
+        check_type_and_value(measure_name, 'new_name')
+        check_type_and_value(formula, 'formula')
+        check_new_name_param(measure_name)
+    elif func_name == 'group_dimensions':
+        group_name, items, position = args[0], args[1], args[2]
+        # check "group_name" param
+        if not isinstance(group_name, str):
+            raise ValueError('Param "group_name" must be "str" type!')
+        if not group_name:
+            raise ValueError('Group name cannot be empty (param "group_name")!')
+        # check items
+        if not isinstance(items, (list, set, tuple)):
+            raise ValueError('Param "dim_items" must be "list", "set" or "tuple" type!')
+        # check position
+        if position not in ["left", "top"]:
+            raise ValueError('Param "position" must be either "left" or "top"!')
+    elif func_name == 'wait_cube_loading':
+        cube_name, time_sleep, max_attempt = args[0], args[1], args[2]
+        # check cube_name
+        if not isinstance(cube_name, str):
+            raise ValueError('Param "cube_name" must be "str" type!')
+        # check time_sleep
+        if not isinstance(time_sleep, int):
+            raise ValueError('Param "time_sleep" must be "int" type!')
+        if time_sleep < 1:
+            raise ValueError('Value of "time_sleep" param must be greater than 0!')
+        # check max_attempt
+        if max_attempt is not None and not isinstance(max_attempt, int):
+            raise ValueError('Param "max_attempt" must be "int" type or None!')
+        if isinstance(max_attempt, int) and max_attempt < 1:
+            raise ValueError('Value of "max_attempt" param must be greater than 0!')
     else:
         raise ValueError("No function to check: {}".format(func_name))
